local tex = Texture.new("gfx/knipe.png", true)

Knife = Core.class(Sprite)

function Knife:init(world, x, y, w, h)
	self.collider = Box.new("knife", world, w, h)
	self.collider.shape.ptr = self
	self:setPosition(x, y)
	
	self.initPos = Vec2.new(x, y)
	
	self.dx = 0
	self.dy = 0
	self.grav = 8000
	self.spin = 0
	self.falling = false
	self.moving = false
	self.sticked = false
	self.speed = -3200
	
	self:createGraphics()
end

function Knife:getShape() return self.collider.shape end
function Knife:createGraphics()
	local w, h = self.collider.shape:getSize():unpack()
	
	self.gr = Bitmap.new(tex)
	self.gr:setScale(1.4, 1.4)
	self.gr:setAnchorPoint(0.5, 0.5)
	self.gr:setRotation(-90)
	self:addChild(self.gr)
end
function Knife:setPosition(x, y)
	Sprite.setPosition(self, x, y)
	self.collider:setPosition(x, y)
end
function Knife:setX(x)
	Sprite.setX(self, x)
	self.collider:setX(x)
end
function Knife:setY(y)
	Sprite.setY(self, y)
	self.collider:setY(y)
end
function Knife:setRotation(r)
	Sprite.setRotation(self, r)
	self.collider:setRotation(r)
end
function Knife:rotateSprite(amount)
	local r = self:getRotation()
	Sprite.setRotation(self, r + amount)
end
function Knife:faceTo(vec)
	local ang = self.collider.shape.pos:angle(vec) + 90
	self:setRotation(ang)
end
function Knife:throw()
	local dir = choose(1,-1)
	self.moving = false
	self.sticked = false
	self.falling = true
	self.spin = math.random(400, 1000) * dir
	self.dx = math.random(500, 1000) * dir
	self.dy = -math.random(1700, 2800)
end


function Knife:updateFall(dt)
	if (self.falling) then
		local x, y = self:getPosition()
		self.dy += self.grav * dt
		x += self.dx * dt
		y += self.dy * dt
		self:rotateSprite(self.spin * dt)
		self:setPosition(x, y)
		
		if (y >= ScreenH + 300 or x <= -150 or x >= ScreenW + 150) then self.falling = false end
	end
end
function Knife:updateRotation(dt, pos, spinSpeed)
	if (self.sticked) then
		local vec = self.collider.shape.pos:copy()
		local r = spinSpeed * dt
		vec:rotateAround(^<r, pos)
		self:setPosition(vec.x, vec.y)
		self:faceTo(pos)
	end
end