local forceX = 1400
local forceY = 800
local grav = 10

MiniBoss = Core.class(Sprite)

function MiniBoss:init(world, container)
	self.world = world
	self.container = container
	
	local g = CreateCircle(40)
	g:setFillColor(RED)
	g:setLineColor(RED, 0.65)
	g:setLineThickness(12)
	self:addChild(g)
	
	self.bullets = {}
end

function MiniBoss:free()
	local l = #self.bullets
	for i = l, 1, -1 do 
		local b = self.bullets[i]
		b.body:setPosition(self:getPosition())
		b.gfx:removeFromParent()
		table.remove(self.bullets, i)
	end	
end

function MiniBoss:shoot(dir)
	local x, y = self:getPosition()
	local body = Circle.new("shuriken", self.world, 25)
	body:setPosition(x, y)
	local g = CreateCircle(25)
	g:setFillColor(WHITE, 0.7)
	g:setLineColor(BLUE, 0.7)
	g:setLineThickness(2)
	g:setPosition(x, y)
	self.container:addChild(g)
	
	dir = dir or choose(1,-1)
	local t = {
		body = body,
		gfx = g,
		odir = -dir,
		dx = forceX * dir,
		dy = forceY,
	}
	
	rawset(self.bullets, #self.bullets + 1, t)
end

function MiniBoss:update(dt)
	local l = #self.bullets
	if (l > 0) then
		for i = l, 1, -1 do 
			local b = self.bullets[i]
			local x, y = b.body:getPosition()
			if (x < -20 or x > ScreenW + 20 or y > ScreenH + 20) then
				b.gfx:removeFromParent()
				table.remove(self.bullets, i)
			else
				x += b.dx * dt
				y += b.dy * dt
				b.dx += forceX * 2 * b.odir * dt
				b.dy += grav * dt
				b.body:setPosition(x, y)
				b.gfx:setPosition(x, y)
			end
		end
	end
end